@@ -2,7 +2,7 @@ import re
 import requests
 import time
 
-class GGGStockInfo():
+class GetStockInfo():
     def __init__(self,API = 'tencent'):
         self.api = API
         
